@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 11768 2019-10-29 10:33:15Z Lavender $
+# $Id: forms.py 11774 2019-11-05 06:26:48Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-10-29 18:33:15 +0800 (週二, 29 十月 2019) $
-# $Revision: 11768 $
+# $Date: 2019-11-05 15:26:48 +0900 (週二, 05 十一月 2019) $
+# $Revision: 11774 $
 
 import os
 import re
@@ -230,44 +230,44 @@ _ShippingAddressForm = get_class(
 Country = get_model('address', 'Country')
     
 class ShippingAddressForm2(_ShippingAddressForm):
-    odererFirstName = forms.CharField(
+    ordererFirstName = forms.CharField(
         label=_('Orderer first name'), required=True)
-    odererLastName = forms.CharField(
+    ordererLastName = forms.CharField(
         label=_('Orderer last name'), required=True)
-    odererLine1 = forms.CharField(
+    ordererLine1 = forms.CharField(
         label=_('Orderer first line of address'), required=True)
-    odererLine4 = forms.CharField(
+    ordererLine4 = forms.CharField(
         label=_('Orderer city'), required=True)
-    odererCountry = forms.ModelChoiceField(
+    ordererCountry = forms.ModelChoiceField(
         label=_('Orderer country'),
         queryset=Country.objects.all(), required=True,
     )
-    odererPostcode = forms.CharField(
+    ordererPostcode = forms.CharField(
         label=_('Orderer postcode'), required=True)
         
     class Meta(_ShippingAddressForm.Meta):
         fields = [
-            'odererFirstName', 'odererLastName', 'odererLine1', 
-            'odererLine4', 'odererCountry', 'odererPostcode',
+            'ordererFirstName', 'ordererLastName', 'ordererLine1', 
+            'ordererLine4', 'ordererCountry', 'ordererPostcode',
         ] + _ShippingAddressForm.Meta.fields
   
     def clean_odererPostcode(self):
-        data = self.cleaned_data['odererPostcode']
-        odererCountry = self.cleaned_data['odererCountry']
+        data = self.cleaned_data['ordererPostcode']
+        ordererCountry = self.cleaned_data['ordererCountry']
         
         if (not data 
-            and self.Meta.model.POSTCODE_REQUIRED and odererCountry):
-            countryCode = odererCountry.iso_3166_1_a2
+            and self.Meta.model.POSTCODE_REQUIRED and ordererCountry):
+            countryCode = ordererCountry.iso_3166_1_a2
             regex = self.Meta.model.POSTCODES_REGEX.get(countryCode, None)
             if regex:
                 msg = _("Addresses in %(country)s require a valid postcode") \
                     % {'country': self.country}
                 raise exceptions.ValidationError(msg)
 
-        if data and odererCountry:
+        if data and ordererCountry:
             # Ensure postcodes are always uppercase
             postcode = data.upper().replace(' ', '')
-            countryCode = odererCountry.iso_3166_1_a2
+            countryCode = ordererCountry.iso_3166_1_a2
             regex = self.Meta.model.POSTCODES_REGEX.get(countryCode, None)
 
             # Validate postcode against regex for the country if available
@@ -300,12 +300,12 @@ def form_valid(self, form):
         not OrdererAddress.objects.filter(user=self.request.user).exists()):
         address = UserAddress.objects.create(
             user=self.request.user,
-            first_name=form.cleaned_data['odererFirstName'],
-            last_name=form.cleaned_data['odererLastName'],
-            line1=form.cleaned_data['odererLine1'],
-            line4=form.cleaned_data['odererLine4'],
-            country=form.cleaned_data['odererCountry'],
-            postcode=form.cleaned_data['odererPostcode'],
+            first_name=form.cleaned_data['ordererFirstName'],
+            last_name=form.cleaned_data['ordererLastName'],
+            line1=form.cleaned_data['ordererLine1'],
+            line4=form.cleaned_data['ordererLine4'],
+            country=form.cleaned_data['ordererCountry'],
+            postcode=form.cleaned_data['ordererPostcode'],
         )
         ordererAddress, created = OrdererAddress.objects.get_or_create(
             user=self.request.user,
