@@ -8,7 +8,10 @@ from django.contrib.auth import get_user_model
 from django.utils.translation import gettext_lazy as _
 from oscar.core.loading import get_model
 
+User = get_user_model()
 UserAddress = get_model('address', 'UserAddress')
+Order = get_model('order', 'Order')
+ShippingAddress = get_model('order', 'ShippingAddress')
 
 TEXT = "text"
 INTEGER = "integer"
@@ -59,7 +62,7 @@ class OptionType(models.Model):
             
 class OrdererAddress(models.Model):
     user = models.ForeignKey(
-        get_user_model(),
+        User,
         related_name='orderer',
         verbose_name=_("Orderer"),
     )
@@ -71,6 +74,38 @@ class OrdererAddress(models.Model):
         verbose_name=_("Orderer Address"),
     )
     
+@property
+def ordererAddress(self):
+    if OrdererAddress.objects.filter(user=self).exists():
+        return OrdererAddress.objects.get(user=self).address
+    else:
+        return None
+        
+User.ordererAddress = ordererAddress
+    
+class OrderOrdererAddress(models.Model):
+    order = models.ForeignKey(
+        Order,
+        related_name='order',
+        verbose_name=_("Order"),
+    )
+    
+    address = models.ForeignKey(
+        ShippingAddress,
+        on_delete=models.CASCADE,
+        related_name='ordererAddress',
+        verbose_name=_("Orderer Address"),
+    )
+    
+@property
+def ordererAddress2(self):
+    if OrderOrdererAddress.objects.filter(order=self).exists():
+        return OrderOrdererAddress.objects.get(order=self).address
+    else:
+        return None
+
+Order.ordererAddress = ordererAddress2
+    
 @property
 def isOrdererAddress(self):
     orderAddress, created = OrdererAddress.objects.get_or_create(
