@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11750 2019-10-15 12:00:08Z Lavender $
+# $Id: views.py 11774 2019-11-05 06:26:48Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-10-15 20:00:08 +0800 (週二, 15 十月 2019) $
-# $Revision: 11750 $ 
+# $Date: 2019-11-05 15:26:48 +0900 (週二, 05 十一月 2019) $
+# $Revision: 11774 $ 
 
 import json
 import logging
@@ -55,7 +55,7 @@ from Iuno.shop import forms
 from Iuno.shop import buildAPIForm
 from Iuno.shop.models import (
     ECPayTrade, AllPayTrade, SpgatewayTrade, CathaybkCreditTrade,
-    ECPayLogisticTrade)
+    ECPayLogisticTrade, OrderOrdererAddress, OrdererAddress)
 from Iuno.shop.Util import createCheckValue
 
 _PaymentDetailsView = get_class('checkout.views', 'PaymentDetailsView')
@@ -228,6 +228,47 @@ class OrderManager(models.Manager):
 
 Order.objects = OrderManager()
 
+# https://code.nuwainfo.com/trac/Mercurius/ticket/3282#ticket
+OrderCreator = get_class('order.utils', 'OrderCreator')
+ShippingAddress = get_model('order', 'ShippingAddress')
+
+_placeOrder = OrderCreator.place_order
+def placeOrder(self, basket, total,  # noqa (too complex (12))
+               shipping_method, shipping_charge, user=None,
+               shipping_address=None, billing_address=None,
+               order_number=None, status=None, request=None, **kwargs):
+    order = _placeOrder(
+        self, basket, total, 
+        shipping_method, shipping_charge, user=user,
+        shipping_address=shipping_address, billing_address=billing_address,
+        order_number=order_number, status=status, request=request, **kwargs)
+   
+    if user:
+        if (user.is_authenticated and 
+            OrdererAddress.objects.filter(user=user).exists()):
+            orderAddress = OrdererAddress.objects.get(user=user)
+            
+            address = ShippingAddress.objects.create(
+                first_name=orderAddress.address.first_name,
+                last_name=orderAddress.address.last_name,
+                line1=orderAddress.address.line1,
+                line4=orderAddress.address.line4,
+                country=orderAddress.address.country,
+                postcode=orderAddress.address.postcode,
+            )
+            
+            orderOrderAddress, created = \
+                OrderOrdererAddress.objects.get_or_create(
+                    order=order,
+                    defaults={
+                        'address': address,
+                    }
+                )
+            
+    return order
+    
+OrderCreator.place_order = placeOrder
+
 # https://code.nuwainfo.com/trac/Mercurius/ticket/3273#ticket
 if VERSION >= (2, 0, 0):
     from oscar.apps.dashboard.catalogue import views as dashboardCatalogueViews
